import { getEndpointPlugin } from "@smithy/middleware-endpoint";
import { getSerdePlugin } from "@smithy/middleware-serde";
import { Command as $Command } from "@smithy/smithy-client";
import { SMITHY_CONTEXT_KEY, } from "@smithy/types";
import { SearchRasterDataCollectionInputFilterSensitiveLog, SearchRasterDataCollectionOutputFilterSensitiveLog, } from "../models/models_0";
import { de_SearchRasterDataCollectionCommand, se_SearchRasterDataCollectionCommand } from "../protocols/Aws_restJson1";
export { $Command };
export class SearchRasterDataCollectionCommand extends $Command {
    static getEndpointParameterInstructions() {
        return {
            UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
            Endpoint: { type: "builtInParams", name: "endpoint" },
            Region: { type: "builtInParams", name: "region" },
            UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" },
        };
    }
    constructor(input) {
        super();
        this.input = input;
    }
    resolveMiddleware(clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        this.middlewareStack.use(getEndpointPlugin(configuration, SearchRasterDataCollectionCommand.getEndpointParameterInstructions()));
        const stack = clientStack.concat(this.middlewareStack);
        const { logger } = configuration;
        const clientName = "SageMakerGeospatialClient";
        const commandName = "SearchRasterDataCollectionCommand";
        const handlerExecutionContext = {
            logger,
            clientName,
            commandName,
            inputFilterSensitiveLog: SearchRasterDataCollectionInputFilterSensitiveLog,
            outputFilterSensitiveLog: SearchRasterDataCollectionOutputFilterSensitiveLog,
            [SMITHY_CONTEXT_KEY]: {
                service: "SageMakerGeospatial",
                operation: "SearchRasterDataCollection",
            },
        };
        const { requestHandler } = configuration;
        return stack.resolve((request) => requestHandler.handle(request.request, options || {}), handlerExecutionContext);
    }
    serialize(input, context) {
        return se_SearchRasterDataCollectionCommand(input, context);
    }
    deserialize(output, context) {
        return de_SearchRasterDataCollectionCommand(output, context);
    }
}
